@@ -1,4 +1,9 @@
 package Google::Tasks;
+# ABSTRACT: Manipulate Google/GMail Tasks
+
+use strict;
+use warnings;
+
 use Moo;
 use namespace::clean;
 use LWP::UserAgent;
@@ -8,7 +13,7 @@ use HTTP::Request::Common;
 use Try::Tiny qw( try catch finally );
 use Carp 'croak';
 
-our $VERSION = '1.0';
+our $VERSION = '1.02'; # VERSION
 
 has json => ( is => 'ro', default => sub { JSON->new } );
 has ua   => (
@@ -406,54 +411,62 @@ sub task_by_name {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Google::Tasks - Manipulate Google/GMail Tasks
 
+=head1 VERSION
+
+version 1.02
+
 =head1 SYNOPSIS
 
-    use Google::Tasks
+    use Google::Tasks;
 
-    my $gt  = Google::Tasks->new;
-    my $gt2 = Google::Tasks->new( user => $user, passwd => $passwd );
+    my $google_tasks = Google::Tasks->new();
+    $google_tasks->login( user => 'user', passwd => 'passwd' );
 
-    $gt->login( user => $user, passwd => $passwd );
+    my $gt = Google::Tasks->new( user => 'user', passwd => 'passwd' );
 
     my $list_object = $gt->lists->[0];
     my $active_list = $gt->active_list;
 
-    $gt->refresh;                  # refresh the current list's data
-    $gt->refresh($list_name);      # switch to a different list
-    $gt->refresh( $list_name, 1 );
+    $gt->refresh;                   # refresh the current list's data
+    $gt->refresh('List Name');      # switch to a different list
+    $gt->refresh( 'List Name', 1 );
 
-    my $list = $gt->add_list($list_name);
-    $gt->drop_list($list_name);
+    my $list = $gt->add_list('List Name');
+    $gt->drop_list('List Name');
 
-    my $list = $gt->rename_list( $current_list_name, $new_list_name );
-    my $list = $gt->clear_list($list_name);
+    my $list2 = $gt->rename_list( 'Current List Name', 'New List Name' );
+    my $list3 = $gt->clear_list('List Name');
 
-    $list->name($new_list_name);
+    $list->name('New List Name');
     $list->save;
     $list->drop;
     $list->clear;
 
-    $gt->drop_task($task_name);
-    $gt->task_by_name($task_name);
+    $gt->drop_task('Task Name');
+    $gt->task_by_name('Task Name');
 
     my $task = $gt->add_task(
-        name      => $task_name,
-        notes     => $notes,
-        completed => $completed_boolean, # defaults false
-        deleted   => $deleted_boolean,   # defaults false
-        task_date => DateTime->now,      # defaults null
+        name      => 'Task Name',
+        notes     => 'Notes',
+        completed => 0,             # defaults false
+        deleted   => 0,             # defaults false
+        task_date => DateTime->now, # defaults null
     );
 
-    $task_a->move(2);
+    $task->move(2);
     $task->move('down');
     $task->move('up');
-    $task_a->move($task_c);
+    $task->move( $gt->task_by_name('Other Task') );
     $task->move($list);
 
     $task->save;
@@ -474,6 +487,9 @@ might find it useful as-is. It's not well-tested and probably never will be.
 And Google could break this entire library by changing their JSON structure.
 Consequently, this module should probably not be used by anyone, ever.
 
+=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Google-Tasks.svg)](https://travis-ci.org/gryphonshafer/Google-Tasks)
+[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Google-Tasks/badge.png)](https://coveralls.io/r/gryphonshafer/Google-Tasks)
+
 =head1 LIBRARY METHODS AND ATTRIBUTES
 
 The following are methods and attributes of the core/parent library
@@ -485,14 +501,14 @@ This instantiator is provided by L<Moo>. It can optionally accept a username
 and password, and if so provided, it will call C<login()> automatically.
 
     my $gt  = Google::Tasks->new;
-    my $gt2 = Google::Tasks->new( user => $user, passwd => $passwd );
+    my $gt2 = Google::Tasks->new( user => 'user', passwd => 'passwd' );
 
 =head2 login
 
 This method accepts a username and password for a valid/current GMail account,
 then attempts to authenticate the user and start up a session with Google Tasks.
 
-    $gt->login( user => $user, passwd => $passwd );
+    $gt->login( user => 'user', passwd => 'passwd' );
 
 The method returns a reference to the object from which the call was made. And
 please note that the authentication takes place via a simple L<LWP::UserAgent>
@@ -536,7 +552,7 @@ current/active list, not all lists. To switch lists, you'll need to C<refresh()>
 to a different list.
 
     $gt->refresh;             # refresh the current list's data
-    $gt->refresh($list_name); # switch to a different list
+    $gt->refresh('List Name'); # switch to a different list
 
 The method returns a reference to the object from which the call was made.
 
@@ -545,7 +561,7 @@ in the spirit of never really deleting anything ever, Google doesn't delete
 deleted tasks. So if you provide an optional second parameter to C<refresh()>
 that's boolean true, it will return tasks that are both deleted and undeleted.
 
-    $gt->refresh( $list_name, 1 );
+    $gt->refresh( 'List Name', 1 );
 
 =head1 LIST LIBRARY METHODS
 
@@ -559,13 +575,13 @@ This method creates a list and returns an object representing the list. The
 object is an instantiation of Google::Tasks::List. The only value to supply,
 which is required, is a text string representing the new list's name
 
-    my $list = $gt->add_list($list_name);
+    my $list = $gt->add_list('List Name');
 
 =head2 drop_list
 
 This method deletes a list based on a name match.
 
-    $gt->drop_list($list_name);
+    $gt->drop_list('List Name');
 
 Note that it is entirely possible to have multiple lists with the same name.
 In those cases, only the first list with matching name is deleted. This method
@@ -575,7 +591,7 @@ returns a reference to the object from which it was called.
 
 This method renames a list based on a name search.
 
-    my $list = $gt->rename_list( $current_list_name, $new_list_name );
+    my $list = $gt->rename_list( 'Current List Name', 'New List Name' );
 
 Note that it is entirely possible to have multiple lists with the same name.
 In those cases, only the first list with matching name is renamed.
@@ -596,7 +612,7 @@ The following are methods of the list sub-library Google::Tasks::List.
 This instantiator requires a text string representing the name of the new list
 and a required "root" parameter, which is an instantiated Google::Tasks object.
 
-    my $list = Google::Tasks::List->new( name =>, $list_name, root => $gt );
+    my $list = Google::Tasks::List->new( name =>, 'List Name', root => $gt );
 
 You probably don't want to ever use this method directly; instead, use the
 C<add_list()> method from Google::Tasks.
@@ -606,7 +622,7 @@ C<add_list()> method from Google::Tasks.
 This is a simple L<Moo> get-er/set-er for the list's name. Changing the name
 value itself won't really do anything useful until you envoke C<save()>.
 
-    $list->name($new_list_name);
+    $list->name('New List Name');
 
 =head2 save
 
@@ -642,11 +658,11 @@ current active list. It requires at minimum the task name. In addition, there
 are quite a few other parameters you can pass in.
 
     my $task = $gt->add_task(
-        name      => $task_name,
-        notes     => $notes,
-        completed => $completed_boolean, # defaults false
-        deleted   => $deleted_boolean,   # defaults false
-        task_date => DateTime->now,      # defaults null
+        name      => 'Task Name',
+        notes     => 'Notes',
+        completed => 0,             # defaults false
+        deleted   => 0,             # defaults false
+        task_date => DateTime->now, # defaults null
     );
 
 Note that "task_date" is a DateTime object, but it's coerced into such when set.
@@ -660,7 +676,7 @@ So you can do stuff like this:
 This method drops a task based on the name of the task. It will look for the
 first task in the current list that has a matching name and will delete it.
 
-    $gt->drop_task($task_name);
+    $gt->drop_task('Task Name');
 
 Note that you can have multiple tasks in a list with the same name. This
 method will only delete the first match.
@@ -670,7 +686,7 @@ method will only delete the first match.
 This method returns the task object from the current active list that matches
 the name provided.
 
-    $gt->task_by_name($task_name);
+    $gt->task_by_name('Task Name');
 
 Note that you can have multiple tasks in a list with the same name. This
 method will only delete the first match.
@@ -687,14 +703,14 @@ object, and either the list object or list ID of the list the task belongs to.
 In addition, there are quite a few other parameters you can pass in.
 
     my $task = Google::Tasks::Task->new(
-        name      => $task_name,
+        name      => 'Task Name',
         root      => $gt,
         list      => $list_obj,
         list_id   => $list_obj->id,
-        notes     => $notes,
-        completed => $completed_boolean, # defaults false
-        deleted   => $deleted_boolean,   # defaults false
-        task_date => DateTime->now,      # defaults null
+        notes     => 'Notes',
+        completed => 0,             # defaults false
+        deleted   => 0,             # defaults false
+        task_date => DateTime->now, # defaults null
     );
 
 Typically, you're not going to want to use this method directly. Instead, use
@@ -720,7 +736,7 @@ represents the index of what the task should be. For example, let's say you have
 a task list with 4 tasks: A, B, C, D. You want to move A between C and D. You'd
 do this:
 
-    $task_a->move(2);
+    $task->move(2);
 
 You can accomplish similar changes by telling C<move()> to "up" or "down" a
 task within a list.
@@ -733,7 +749,7 @@ pass it a list object, it will move the task to be under (indented) to that
 task. For example, if you have a list with tasks A, B, C, and D, and you want
 to move A indented under C:
 
-    $task_a->move($task_c);
+    $task->move( $gt->task_by_name('Other Task') );
 
 If you pass a list object, the task (and any of its subordinate tasks if any)
 will get moved under the new list.
@@ -750,15 +766,47 @@ This will delete the task.
 
 L<Google::OAuth>, L<Google::API::Client>, L<Moo>.
 
+You can also look for additional information at:
+
+=over 4
+
+=item *
+
+L<GitHub|https://github.com/gryphonshafer/Google-Tasks>
+
+=item *
+
+L<CPAN|http://search.cpan.org/dist/Google-Tasks>
+
+=item *
+
+L<MetaCPAN|https://metacpan.org/pod/Google::Tasks>
+
+=item *
+
+L<AnnoCPAN|http://annocpan.org/dist/Google-Tasks>
+
+=item *
+
+L<Travis CI|https://travis-ci.org/gryphonshafer/Google-Tasks>
+
+=item *
+
+L<Coveralls|https://coveralls.io/r/gryphonshafer/Google-Tasks>
+
+=back
+
+=for Pod::Coverage BUILD is_authed json passwd ua user
+
 =head1 AUTHOR
 
-Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
+Gryphon Shafer <gryphon@cpan.org>
 
-  code('Perl') || die;
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2015 by Gryphon Shafer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
